
/********************************************************************\
 * gnc-warnings.h -- overview of warning messages that can be       *
 *                  displayed to the user always or once.           *
 *                                                                  *
 * ATTENTION: this file is autogenerated based on the gsettings     *
 *    schema file org.gnucash.GnuCash.warnings.gschema.xml.in       *
 *                                                                  *
 * If you need any modifications in this file, please update the    *
 * schema source file (or the xsl translation file depending on the *
 * kind of change required) instead.                                *
 *                                                                  *
 * Copyright (C) 2013 Geert Janssens <geert@kobaltwit.be>     *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 *                                                                  *
\********************************************************************/

#ifndef GNC_WARNINGS_H
#define GNC_WARNINGS_H

#include <glib.h>


#define GNC_PREF_WARN_CHECKPRINTING_MULTI_ACCT "checkprinting-multi-acct"
#define GNC_PREF_WARN_CLOSING_WINDOW_QUESTION "closing-window-question"
#define GNC_PREF_WARN_INV_ENTRY_MOD "inv-entry-mod"
#define GNC_PREF_WARN_INV_ENTRY_DUP "inv-entry-dup"
#define GNC_PREF_WARN_PRICE_COMM_DEL "price-comm-del"
#define GNC_PREF_WARN_PRICE_COMM_DEL_QUOTES "price-comm-del-quotes"
#define GNC_PREF_WARN_PRICE_QUOTES_DEL "price-quotes-del"
#define GNC_PREF_WARN_PRICE_QUOTES_REPLACE "price-quotes-replace"
#define GNC_PREF_WARN_REG_IS_ACCT_PAY_REC "reg-is-acct-pay-rec"
#define GNC_PREF_WARN_REG_IS_READ_ONLY "reg-is-read-only"
#define GNC_PREF_WARN_REG_RECD_SPLIT_MOD "reg-recd-split-mod"
#define GNC_PREF_WARN_REG_RECD_SPLIT_UNREC "reg-recd-split-unrec"
#define GNC_PREF_WARN_REG_SPLIT_CUT "reg-split-cut"
#define GNC_PREF_WARN_REG_SPLIT_CUT_RECD "reg-split-cut-recd"
#define GNC_PREF_WARN_REG_SPLIT_DEL "reg-split-del"
#define GNC_PREF_WARN_REG_SPLIT_DEL_RECD "reg-split-del-recd"
#define GNC_PREF_WARN_REG_SPLIT_DEL_ALL "reg-split-del-all"
#define GNC_PREF_WARN_REG_SPLIT_DEL_ALL_RECD "reg-split-del-all-recd"
#define GNC_PREF_WARN_REG_TRANS_CUT "reg-trans-cut"
#define GNC_PREF_WARN_REG_TRANS_CUT_RECD "reg-trans-cut-recd"
#define GNC_PREF_WARN_REG_TRANS_DEL "reg-trans-del"
#define GNC_PREF_WARN_REG_TRANS_DEL_RECD "reg-trans-del-recd"
#define GNC_PREF_WARN_REG_TRANS_DUP "reg-trans-dup"
#define GNC_PREF_WARN_REG_TRANS_MOD "reg-trans-mod"
#define GNC_PREF_WARN_REG_TRANS_JUMP_MULTIPLE_SPLITS "reg-trans-jump-multiple-splits"
#define GNC_PREF_WARN_REG_TRANS_JUMP_SINGLE_ACCOUNT "reg-trans-jump-single-account"

enum {
    WARN_CHECKPRINTING_MULTI_ACCT,
    WARN_CLOSING_WINDOW_QUESTION,
    WARN_INV_ENTRY_MOD,
    WARN_INV_ENTRY_DUP,
    WARN_PRICE_COMM_DEL,
    WARN_PRICE_COMM_DEL_QUOTES,
    WARN_PRICE_QUOTES_DEL,
    WARN_PRICE_QUOTES_REPLACE,
    WARN_REG_IS_ACCT_PAY_REC,
    WARN_REG_IS_READ_ONLY,
    WARN_REG_RECD_SPLIT_MOD,
    WARN_REG_RECD_SPLIT_UNREC,
    WARN_REG_SPLIT_CUT,
    WARN_REG_SPLIT_CUT_RECD,
    WARN_REG_SPLIT_DEL,
    WARN_REG_SPLIT_DEL_RECD,
    WARN_REG_SPLIT_DEL_ALL,
    WARN_REG_SPLIT_DEL_ALL_RECD,
    WARN_REG_TRANS_CUT,
    WARN_REG_TRANS_CUT_RECD,
    WARN_REG_TRANS_DEL,
    WARN_REG_TRANS_DEL_RECD,
    WARN_REG_TRANS_DUP,
    WARN_REG_TRANS_MOD,
    WARN_REG_TRANS_JUMP_MULTIPLE_SPLITS,
    WARN_REG_TRANS_JUMP_SINGLE_ACCOUNT,
};

typedef struct GncWarningSpec
{
  const gchar *warn_name;
  const gchar *warn_desc;
  const gchar *warn_long_desc;
} GncWarningSpec;

const GncWarningSpec *gnc_get_warnings (void);

#endif /* GNC_WARNINGS_H */
